Welcome to NeuroKit's documentation!
======================================

.. toctree::
   :maxdepth: 2

   installation
   news
   tutorials/index
   functions
   contributing
   credits

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
